@@ -175,6 +175,7 @@ CURLVERSION_SEVENTH
 CURLVERSION_SIXTH
 CURLVERSION_TENTH
 CURLVERSION_THIRD
+CURLVERSION_TWELFTH
 CURLUSESSL_ALL
 CURLUSESSL_CONTROL
 CURLUSESSL_NONE
@@ -217,6 +218,7 @@ CURLUE_NO_USER
 CURLUE_NO_ZONEID
 CURLUE_OK
 CURLUE_OUT_OF_MEMORY
+CURLUE_TOO_LARGE
 CURLUE_UNKNOWN_PART
 CURLUE_UNSUPPORTED_SCHEME
 CURLUE_URLDECODE
@@ -234,6 +236,7 @@ CURLSSLOPT_NATIVE_CA
 CURLSSLOPT_NO_PARTIALCHAIN
 CURLSSLOPT_NO_REVOKE
 CURLSSLOPT_REVOKE_BEST_EFFORT
+CURLSSLBACKEND_AWSLC
 CURLSSLBACKEND_AXTLS
 CURLSSLBACKEND_BEARSSL
 CURLSSLBACKEND_BORINGSSL
@@ -311,6 +314,7 @@ CURLPX_UNKNOWN_MODE
 CURLPX_USER_REJECTED
 CURLPROXY_HTTP
 CURLPROXY_HTTPS
+CURLPROXY_HTTPS2
 CURLPROXY_HTTP_1_0
 CURLPROXY_SOCKS4
 CURLPROXY_SOCKS4A
@@ -416,6 +420,7 @@ CURLOPT_DOH_SSL_VERIFYHOST
 CURLOPT_DOH_SSL_VERIFYPEER
 CURLOPT_DOH_SSL_VERIFYSTATUS
 CURLOPT_DOH_URL
+CURLOPT_ECH
 CURLOPT_EGDSOCKET
 CURLOPT_ENCODING
 CURLOPT_ERRORBUFFER
@@ -446,6 +451,7 @@ CURLOPT_FTP_USE_PRET
 CURLOPT_GSSAPI_DELEGATION
 CURLOPT_HAPPY_EYEBALLS_TIMEOUT_MS
 CURLOPT_HAPROXYPROTOCOL
+CURLOPT_HAPROXY_CLIENT_IP
 CURLOPT_HEADER
 CURLOPT_HEADERDATA
 CURLOPT_HEADERFUNCTION
@@ -491,6 +497,7 @@ CURLOPT_MAIL_AUTH
 CURLOPT_MAIL_FROM
 CURLOPT_MAIL_RCPT
 CURLOPT_MAIL_RCPT_ALLLOWFAILS
+CURLOPT_MAIL_RCPT_ALLOWFAILS
 CURLOPT_MAXAGE_CONN
 CURLOPT_MAXCONNECTS
 CURLOPT_MAXFILESIZE
@@ -593,6 +600,7 @@ CURLOPT_SASL_IR
 CURLOPT_SEEKDATA
 CURLOPT_SEEKFUNCTION
 CURLOPT_SERVER_RESPONSE_TIMEOUT
+CURLOPT_SERVER_RESPONSE_TIMEOUT_MS
 CURLOPT_SERVICE_NAME
 CURLOPT_SHARE
 CURLOPT_SOCKOPTDATA
@@ -641,6 +649,7 @@ CURLOPT_STREAM_WEIGHT
 CURLOPT_SUPPRESS_CONNECT_HEADERS
 CURLOPT_TCP_FASTOPEN
 CURLOPT_TCP_KEEPALIVE
+CURLOPT_TCP_KEEPCNT
 CURLOPT_TCP_KEEPIDLE
 CURLOPT_TCP_KEEPINTVL
 CURLOPT_TCP_NODELAY
@@ -750,6 +759,7 @@ CURLINFO_CERTINFO
 CURLINFO_CONDITION_UNMET
 CURLINFO_CONNECT_TIME
 CURLINFO_CONNECT_TIME_T
+CURLINFO_CONN_ID
 CURLINFO_CONTENT_LENGTH_DOWNLOAD
 CURLINFO_CONTENT_LENGTH_DOWNLOAD_T
 CURLINFO_CONTENT_LENGTH_UPLOAD
@@ -794,6 +804,7 @@ CURLINFO_PROXYAUTH_AVAIL
 CURLINFO_PROXY_ERROR
 CURLINFO_PROXY_SSL_VERIFYRESULT
 CURLINFO_PTR
+CURLINFO_QUEUE_TIME_T
 CURLINFO_REDIRECT_COUNT
 CURLINFO_REDIRECT_TIME
 CURLINFO_REDIRECT_TIME_T
@@ -830,6 +841,8 @@ CURLINFO_TLS_SSL_PTR
 CURLINFO_TOTAL_TIME
 CURLINFO_TOTAL_TIME_T
 CURLINFO_TYPEMASK
+CURLINFO_USED_PROXY
+CURLINFO_XFER_ID
 CURLHSTS_ENABLE
 CURLHSTS_READONLYFILE
 CURLHE_BADINDEX
@@ -913,6 +926,7 @@ CURLE_CONV_REQD
 CURLE_COULDNT_CONNECT
 CURLE_COULDNT_RESOLVE_HOST
 CURLE_COULDNT_RESOLVE_PROXY
+CURLE_ECH_REQUIRED
 CURLE_FAILED_INIT
 CURLE_FILESIZE_EXCEEDED
 CURLE_FILE_COULDNT_READ_FILE
@@ -1008,6 +1022,7 @@ CURLE_TFTP_NOSUCHUSER
 CURLE_TFTP_NOTFOUND
 CURLE_TFTP_PERM
 CURLE_TFTP_UNKNOWNID
+CURLE_TOO_LARGE
 CURLE_TOO_MANY_REDIRECTS
 CURLE_UNKNOWN_OPTION
 CURLE_UNKNOWN_TELNET_OPTION
